@@ -1,20 +1,18 @@
-from __future__ import print_function
-
-from abc import ABCMeta, abstractmethod
 import logging
 import os
+from abc import ABCMeta, abstractmethod
 
 from cloudbridge.cloud.factory import CloudProviderFactory, ProviderList
-from genomespaceclient import util
-import requests
 
+from genomespaceclient import util
+
+import requests
 
 try:
     from urllib.parse import urlparse
 except ImportError:
     from urlparse import urlparse
 
-
 log = logging.getLogger(__name__)
 
 
@@ -73,8 +71,7 @@ class SimpleStorageHandler(StorageHandler):
                           " copied".format(
                               progress=util.format_file_size(bytes_copied),
                               total=util.format_file_size(int(total_length))
-                              if total_length else "unknown size"),
-                          end='\r')
+                              if total_length else "unknown size", end='\r'))
             if log.isEnabledFor(logging.INFO):
                 print("\n")
 
@@ -88,8 +85,8 @@ class S3StorageHandler(SimpleStorageHandler):
             {'aws_access_key': creds["accessKey"],
              'aws_secret_key': creds["secretKey"],
              'aws_session_token': creds["sessionToken"]})
-        bucket = provider.object_store.get(upload_info['s3BucketName'])
-        obj = bucket.create_object(upload_info['s3ObjectKey'])
+        bucket = provider.storage.buckets.get(upload_info['s3BucketName'])
+        obj = bucket.objects.create(upload_info['s3ObjectKey'])
         obj.upload_from_file(source)
 
 
@@ -102,6 +99,6 @@ class SwiftStorageHandler(SimpleStorageHandler):
             ProviderList.OPENSTACK,
             {'os_storage_url': upload_info["swiftFileUrl"],
              'os_auth_token': upload_info["token"]})
-        bucket = provider.object_store.get(container)
-        obj = bucket.create_object(location)
+        bucket = provider.storage.buckets.get(container)
+        obj = bucket.objects.create(location)
         obj.upload_from_file(source)
